==> QupZilla-2.2.1.tar.xz: QupZilla-2.2.1/src/plugins/TabManager/translations/tr_TR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr_TR" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Sekme Yöneticisi Ayarları</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Lütfen görünüm türü seçin:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>YanÇubuk</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>TabManager eklenti için ana TabBar yerine kullanın.
</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Sekme Yöneticisi</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="98"/>
        <source>Local File System:</source>
        <translation>Yerel Dosya Sistemi:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="101"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="104"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="250"/>
        <source>Group by</source>
        <translation>Şuna Göre Grupla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="251"/>
        <source>&amp;Window</source>
        <translation>&amp;Pencere</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="256"/>
        <source>&amp;Domain</source>
        <translation>&amp;Alan adı</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="261"/>
        <source>&amp;Host</source>
        <translation>&amp;Yer sağlayıcı</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="269"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;Yan yana göster</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="275"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Kontrol edilmiş sekmeleri ayır</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="276"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>&amp;Kontrol edilmiş sekmeler yer imi</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Close checked tabs</source>
        <translation>&amp;Kontrol edilmiş sekmeleri kapat</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="528"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Yer imleri için dizin seçin: </translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="529"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Seçilen Sekmeleri Yer İmlerine Ekle</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="646"/>
        <source>Window %1</source>
        <translation>Pencere %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="647"/>
        <source>Double click to switch</source>
        <translation>Değiştirmek için çift tıklayın</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Sekme Yöneticisi</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Sekme Yöneticisini Göster</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.4.tar.xz: QupZilla-2.2.4/src/plugins/TabManager/translations/tr_TR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr_TR" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Sekme Yöneticisi Ayarları</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Lütfen görünüm türü seçin:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Kenar Çubuğu</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Pencer</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>TabManager eklenti için ana TabBar yerine kullanın.
</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Sekme Yöneticisi</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="110"/>
        <source>Local File System:</source>
        <translation>Yerel Dosya Sistemi:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="113"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="116"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="301"/>
        <source>Group by</source>
        <translation>Grupla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="302"/>
        <source>&amp;Window</source>
        <translation>&amp;Pencere</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="307"/>
        <source>&amp;Domain</source>
        <translation>&amp;Alan adı</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="312"/>
        <source>&amp;Host</source>
        <translation>&amp;Yer sağlayıcı</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="320"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;Yan yana göster</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="326"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Kontrol edilmiş sekmeleri ayır</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="327"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>&amp;Kontrol edilmiş sekmeler yer imi</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="328"/>
        <source>&amp;Close checked tabs</source>
        <translation>&amp;Kontrol edilmiş sekmeleri kapat</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="582"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Yer imleri için dizin seçin: </translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="583"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Seçilen Sekmeleri Yer İmlerine Ekle</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="685"/>
        <source>Window %1</source>
        <translation>Pencere %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="686"/>
        <source>Double click to switch</source>
        <translation>Değiştirmek için çift tıklayın</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Sekme Yöneticisi</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Sekme Yöneticisini Göster</translation>
    </message>
</context>
</TS>
